@@ -53,18 +53,36 @@
 (test-equal
     (call-with-output-string
       (lambda (p)
-        (aa-map-keys
-         (lambda (k) (display k p))
+        (aa-for-each
+         (lambda (kv) (display (car kv) p))
          (aa-insert (aa-insert (aa-insert #nil "b" 2) "e" 5) "a" 1))))
   "abe")
 
 (test-equal
     (call-with-output-string
       (lambda (p)
-        (aa-map-values
-         (lambda (v) (display v p))
+        (aa-for-each-reverse
+         (lambda (kv) (display (car kv) p))
          (aa-insert (aa-insert (aa-insert #nil "b" 2) "e" 5) "a" 1))))
-  "125")
+  "eba")
+
+(test-equal
+    (aa-map-keys
+     (lambda (k) (string-append k "q"))
+     (aa-insert (aa-insert (aa-insert #nil "b" 2) "e" 5) "a" 1))
+  '("aq" "bq" "eq"))
+
+(test-equal
+    (aa-map-reverse
+     (lambda (kv) (string-append (car kv) "q"))
+     (aa-insert (aa-insert (aa-insert #nil "b" 2) "e" 5) "a" 1))
+  '("eq" "bq" "aq"))
+
+(test-equal
+    (aa-map-values
+     (lambda (v) (* 2 v))
+     (aa-insert (aa-insert (aa-insert #nil "b" 2) "e" 5) "a" 1))
+  '(2 4 10))
 
 (test-equal
     (aa-to-list (aa-insert (aa-insert (aa-insert #nil "e" 5) "a" 1) "b" 2))
